.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents:
=========

.. toctree::
   :maxdepth: 2

   installation
   usage
   lenstronomy
   contributing
   mailinglist
   authors
   published
   affiliatedpackages
   history

Feedback
========

If you have any suggestions or questions about **lenstronomy** feel free to email me
at sibirrer@gmail.com.

If you encounter any errors or problems with **lenstronomy**, please let me know!